| Title: | Visualisation and Annotation of 360 Degree Imagery |
| Version: | 1.1.0 |
| Description: | Provides a customisable R 'shiny' app for immersively visualising, mapping and annotating panospheric (360 degree) imagery. The flexible interface allows annotation of any geocoded images using up to 4 user specified drop-down menus. The app uses 'leaflet' to render maps that display the geo-locations of images and Panellum https://pannellum.org/, a lightweight panorama viewer for the web, to render images in virtual 360 degree viewing mode. Key functions include the ability to draw on & export parts of 360 images for downstream applications. Users can also draw polygons and points on map imagery related to the panoramic images and export them for further analysis. Downstream applications include using annotations to train Artificial Intelligence/Machine Learning (AI/ML) models and geospatial modelling and analysis of camera based survey data. |
| Depends: | R (≥ 4.4.0) |
| License: | GPL (≥ 3) |
| URL: | https://github.com/NunzioKnerr/pannotator_package_source |
| BugReports: | https://github.com/NunzioKnerr/pannotator_package_source/issues |
| Imports: | bslib, colourpicker, config, configr, dplyr, exiftoolr, geojsonsf, ggplot2, golem, graphics, grDevices, htmltools, htmlwidgets, jpeg, jsonify, jsonlite, leaflet, leafpm, rintrojs, rhandsontable, scales, sf, shiny, shinyFiles, shinyhelper, shinyjs, shinyWidgets, tools, utils |
| Suggests: | httpuv, knitr, rmarkdown, spelling, testthat (≥ 3.0.0) |
| VignetteBuilder: | knitr |
| Config/testthat/edition: | 3 |
| Encoding: | UTF-8 |
| Language: | en-US |
| RoxygenNote: | 7.3.3 |
| NeedsCompilation: | no |
| Packaged: | 2026-05-26 03:12:18 UTC; kne01b |
| Author: | Nunzio Knerr |
| Maintainer: | Nunzio Knerr <Nunzio.Knerr@csiro.au> |
| Repository: | CRAN |
| Date/Publication: | 2026-05-26 03:30:02 UTC |
Run the Shiny Application
Description
'run_app()' starts the Shiny application contained in this package, with an option to load settings from a YAML file using 'projectSettingsFile = "pathToYamlFile"'.
Usage
run_app(
onStart = NULL,
options = list(),
enableBookmarking = NULL,
uiPattern = "/",
projectSettingsFile = NULL,
...
)
Arguments
onStart |
A function that will be called before the app is actually run.
This is only needed for |
options |
Named options that should be passed to the |
enableBookmarking |
Can be one of |
uiPattern |
A regular expression that will be applied to each |
projectSettingsFile |
Optional path to a project YAML file to load at startup. |
... |
Additional arguments to pass to 'golem_opts'. See '?golem::get_golem_options' for more details. |
Details
This function initializes and runs the Shiny app developed with the golem framework. It optionally loads application-specific settings from a YAML file, which can be useful for project-specific configurations. Project YAML files can be exported from the Settings panel inside the app.
Value
No return value, called for side effects. Launches the Shiny app.
Examples
if (interactive()) {
# Example: Run the application with default settings
options(shiny.port=httpuv::randomPort(),
shiny.launch.browser = .rs.invokeShinyWindowExternal,
shiny.maxRequestSize=9000*1024^2)
run_app()
# Example: Run the application with a project YAML exported from Settings
run_app(projectSettingsFile = "C:/test-project.yml")
}